package com.proximity.demo.eventbriteApi.Events;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.proximity.demo.eventbriteApi.Categories.Category;
import com.proximity.demo.eventbriteApi.Subcategories.Subcategory;

import javax.persistence.*;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.Map;

@Entity
@JsonIgnoreProperties(ignoreUnknown = true)
@Table(name="EVENT")
public class Event {

    @Id
    private long id;
    private String eventName;
    private String eventDescription;
    private Long category_id;
    private Long subcategory_id;
    private Long venue_id;
    private LocalDate start_date;
    private LocalDate endDate;
    private String status;
    private Date created;
    private String resource_url;
//    private String logo;


    @ManyToOne
    @JoinColumn(name = "category_id", insertable = false, updatable = false)
    private Category category;

    @ManyToOne
    @JoinColumn(name = "subcategory_id", insertable = false, updatable = false)
    private Subcategory subcategory;

//    @ManyToOne
//    @JsonBackReference
//    @JoinColumn(name = "venue_id", insertable = false, updatable = false)
//    private Venue venue;

    public Event() { }

    public Event(String eventName, String eventDescription, long category_id, long subcategory_id, long venue_id,
                 LocalDate start_date, LocalDate endDate, String status, Date created, String resource_url,
                 String logo) {
        this.eventName = eventName;
        this.eventDescription = eventDescription;
        this.category_id = category_id;
        this.subcategory_id = subcategory_id;
        this.venue_id = venue_id;
        this.start_date = start_date;
        this.endDate = endDate;
        this.status = status;
        this.created = created;
        this.resource_url = resource_url;
//        this.logo = logo;
//        this.venue = venue;
    }

    @JsonProperty("name")
    private void unpackName(Map<String, Object> name) {
        this.eventName = (String) name.get("text");
    }

    @JsonProperty("description")
    private void unpackDescription(Map<String, Object> description) {
        this.eventDescription = (String) description.get("text");
    }

    @JsonProperty("start")
    private void unpackStart(Map<String, Object> start) {
        this.start_date = LocalDate.from(LocalDateTime.parse((String) start.get("local")));
    }

    @JsonProperty("end")
    private void unpackEnd(Map<String, Object> end) {
        this.endDate = LocalDate.from(LocalDateTime.parse((String) end.get("local")));
    }
//
//    @JsonProperty("logo")
//    private void unpackLogo(Map<String, Object> logo) {
//        this.logo = (String) logo.get("url");
//    }

    public long getId() { return id; }

    public void setId(long id) { this.id = id; }

    public String getEventName() { return eventName; }

    public void setEventName(String eventName) { this.eventName = eventName; }

    public String getEventDescription() { return eventDescription; }

    public void setEventDescription(String eventDescription) { this.eventDescription = eventDescription; }

    public Long getCategory_id() { return category_id; }

    public void setCategory_id(Long category_id) { this.category_id = category_id; }

    public Long getSubcategory_id() { return subcategory_id; }

    public void setSubcategory_id(Long subcategory_id) { this.subcategory_id = subcategory_id; }

    public void setVenue_id(Long venue_id) { this.venue_id = venue_id; }

    public long getVenue_id() { return venue_id; }

    public void setVenue_id(long venue_id) { this.venue_id = venue_id; }

    public LocalDate getStart_date() {
        return start_date;
    }

    public void setStart_date(LocalDate start_date) {
        this.start_date = start_date;
    }

    public LocalDate getEndDate() {
        return endDate;
    }

    public void setEndDate(LocalDate endDate) {
        this.endDate = endDate;
    }

    public String getStatus() { return status; }

    public void setStatus(String status) { this.status = status; }

    public Date getCreated() { return created; }

    public void setCreated(Date created) { this.created = created; }

    public String getResource_url() { return resource_url; }

    public void setResource_url(String resource_url) { this.resource_url = resource_url; }

//    public String getLogo() { return logo; }
//
//    public void setLogo(String logo) { this.logo = logo; }

    public Category getCategory() { return category; }

    public void setCategory(Category category) { this.category = category; }

    public Subcategory getSubcategory() { return subcategory; }

    public void setSubcategory(Subcategory subcategory) { this.subcategory = subcategory; }

//    public Venue getVenue() { return venue; }
//
//    public void setVenue(Venue venue) { this.venue = venue; }

}
